@@ -20,6 +20,10 @@
  
 #include "dialog_invalid_data.h"
 #include <glom/libglom/data_structure/glomconversions.h>
+#include <glom/libglom/utils.h>
+
+namespace Glom
+{
 
 /** Show the dialog.
  * @result true if the data in the field should be reverted.
@@ -32,8 +36,8 @@ bool glom_show_dialog_invalid_data(Field::glom_field_type glom_type)
   refXml->get_widget_derived("dialog_data_invalid_format", dialog);
   dialog->set_example_data(glom_type);
   //dialog->set_transient_for(*this);
-  int response = dialog->run();
-
+  int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_data_invalid_format");
+  
   delete dialog;
   return (response == 2); //The glade file has a response of 2 for the Revert button.
 }
@@ -60,7 +64,7 @@ void Dialog_InvalidData::set_example_data(Field::glom_field_type glom_type)
       date.day = 31;
       date.month = 1;
       date.year = 2005;
-      example_text = GlomConversions::get_text_for_gda_value(glom_type, Gnome::Gda::Value(date));
+      example_text = Conversions::get_text_for_gda_value(glom_type, Gnome::Gda::Value(date));
       break;
     }
     case(Field::TYPE_TIME):
@@ -69,13 +73,13 @@ void Dialog_InvalidData::set_example_data(Field::glom_field_type glom_type)
       time.hour = 13;
       time.minute = 02;
       time.second = 03;
-      example_text = GlomConversions::get_text_for_gda_value(glom_type, Gnome::Gda::Value(time));
+      example_text = Conversions::get_text_for_gda_value(glom_type, Gnome::Gda::Value(time));
       break;
     }
     case(Field::TYPE_NUMERIC):
     {
       Gnome::Gda::Value gda_value(12345678.91);
-      example_text = GlomConversions::get_text_for_gda_value(glom_type, gda_value);
+      example_text = Conversions::get_text_for_gda_value(glom_type, gda_value);
       break;
     }
     case(Field::TYPE_TEXT):
@@ -89,3 +93,5 @@ void Dialog_InvalidData::set_example_data(Field::glom_field_type glom_type)
   if(m_label)
     m_label->set_text(example_text);
 }
+
+} //namespace Glom
