@@ -32,7 +32,12 @@
 #include <glom/mode_design/dialog_add_related_table.h>
 #include <glom/mode_design/script_library/dialog_script_library.h>
 #include <glom/dialog_new_self_hosted_connection.h>
+
+//#define ENABLE_RELATIONSHIPS_OVERVIEW
+#ifdef ENABLE_RELATIONSHIPS_OVERVIEW
 #include "relationships_overview/dialog_relationships_overview.h"
+#endif
+
 #include "filechooser_export.h"
 #include <glom/glom_privs.h>
 #include <sstream> //For stringstream.
@@ -953,10 +958,7 @@ Gtk::Window* Frame_Glom::get_app_window()
 
 void Frame_Glom::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
 {
-  Gtk::MessageDialog dialog("<b>" + title + "</b>", true /* markup */, message_type, Gtk::BUTTONS_OK);
-  dialog.set_secondary_text(message);
-  dialog.set_transient_for(parent);
-  dialog.run();
+  Utils::show_ok_dialog(title, message, parent, message_type);
 }
 
 void Frame_Glom::on_button_quickfind()
@@ -1247,8 +1249,10 @@ void Frame_Glom::do_menu_developer_fields(Gtk::Window& parent)
   }
 }
 
+
 void Frame_Glom::on_menu_developer_relationships_overview()
 {
+#ifdef ENABLE_RELATIONSHIPS_OVERVIEW
   Dialog_RelationshipsOverview* dialog = 0;
   try
   {
@@ -1271,8 +1275,12 @@ void Frame_Glom::on_menu_developer_relationships_overview()
   {
     std::cerr << ex.what() << std::endl;
   }
+#else
+  show_ok_dialog(_("Not Implemented"), _("This feature is not yet available."), *get_app_window(), Gtk::MESSAGE_WARNING);
+#endif //ENABLE_RELATIONSHIPS_OVERVIEW
 }
 
+
 void Frame_Glom::on_menu_developer_relationships()
 {
   //Check that there is a table to show:
@@ -1424,18 +1432,43 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     }
 
     add_view(dialog);
-    response = Glom::Utils::dialog_run_with_help(dialog, "dialog_new_self_hosted_connection");
+
+
+    response = Gtk::RESPONSE_OK;
+    bool keep_trying = true;
+    while(keep_trying)
+    {
+      response = Glom::Utils::dialog_run_with_help(dialog, "dialog_new_self_hosted_connection");
+
+      //Check the password is acceptable:
+      if(response == Gtk::RESPONSE_OK)
+      {
+        const bool password_ok = dialog->check_password();
+        if(password_ok)
+        {
+          keep_trying = false; //Everything is OK.
+        }
+      }
+      else
+        keep_trying = false; //The user cancelled.
+
+    }
+
     dialog->hide();
  
     // Create the requested self-hosting database:
     bool created = false;
     if(response == Gtk::RESPONSE_OK)
     {
-      created = dialog->create_self_hosted(); //TODO: Tell the user.
+      created = dialog->create_self_hosted();
       if(created)
       {
-        connection_pool->start_self_hosting();
+        const bool test = connection_pool->start_self_hosting();
+        if(!test)
+          return false;
       }
+      else
+        return false;
 
       //dialog->create_self_hosted() has already set enough information in the ConnectionPool to allow a connection so we can create the database in the new database cluster:
      
