@@ -25,9 +25,6 @@
 #include <glom/libglom/sharedptr.h>
 #include <glom/libglom/data_structure/fieldtypes.h>
 
-typedef struct AvahiEntryGroup AvahiEntryGroup;
-typedef struct AvahiClient AvahiClient;
-
 namespace Gtk
 {
   class Window;
@@ -36,6 +33,8 @@ namespace Gtk
 namespace Glom
 {
 
+class AvahiPublisher;
+
 class ExceptionConnection : public std::exception
 {
 public:
@@ -140,15 +139,16 @@ public:
 
   /** Start a database server instance for the exisiting database files.
    */
-  void start_self_hosting();
+  bool start_self_hosting();
 
   /** Stop the database server instance for the database files.
    */
   void stop_self_hosting();
 
   /** Create new database files, for later use by their own  database server instance.
+   * @param parent_window A parent window to use as the transient window when displaying errors.
    */
-  bool create_self_hosting();
+  bool create_self_hosting(Gtk::Window* parent_window);
 
   //Show the gda error in a dialog.
   static bool handle_error(bool cerr_only = false);
@@ -181,10 +181,11 @@ protected:
   void avahi_start_publishing();
   void avahi_stop_publishing();
 
-public:
-  void avahi_create_services(AvahiClient *c);
 protected:
 
+  //bool directory_exists_filepath(const std::string& filepath);
+  bool directory_exists_uri(const std::string& uri);
+
   typedef std::list<Glib::ustring> type_list_ports;
   type_list_ports m_list_ports; //Network ports on which to try connecting to postgres.
 
@@ -202,10 +203,7 @@ protected:
   float m_postgres_server_version;
 
 public:
-  AvahiEntryGroup* m_avahi_group;
-  AvahiClient* m_avahi_client;
-  GMainLoop* m_avahi_mainloop;
-  Glib::ustring m_avahi_service_name;
+  AvahiPublisher* m_avahi_publisher;
 
 private:
 
